@@ -136,7 +136,8 @@ static struct {
 static void obc_reset(ObcContext *ctx, gboolean connect);
 static void process_input(ObcContext *ctx, char *input);
 
-static char *response_to_string(int rsp) {
+static char *response_to_string(int rsp)
+{
     const char *str;
     char *ret;
     int i;
@@ -168,7 +169,8 @@ static char *response_to_string(int rsp) {
     return ret;
 }
 
-static gboolean is_bda(const char *bda) {
+static gboolean is_bda(const char *bda)
+{
    int i;
     if (strlen(bda) != 17)
         return FALSE;
@@ -179,7 +181,8 @@ static gboolean is_bda(const char *bda) {
     return TRUE;
 }
 
-static char *get_device_name(ObcContext *ctx) {
+static char *get_device_name(ObcContext *ctx)
+{
     if (ctx->cwd[0] == '\0')
         return g_strdup("disconnected");
     if (ctx->user_dev)
@@ -221,7 +224,8 @@ static char *get_device_name(ObcContext *ctx) {
     return g_strdup("");
 }
 
-static void obc_main(ObcContext *ctx) {
+static void obc_main(ObcContext *ctx)
+{
     while (TRUE) {
         char *name, *prompt, *cmd, *lf;
 #ifndef HAVE_LIBREADLINE
@@ -262,7 +266,8 @@ static void obc_main(ObcContext *ctx) {
     }
 }
 
-static gchar *get_preferred_bda(void) {
+static gchar *get_preferred_bda(void)
+{
 #ifdef USE_BTCOND
     if (gcclient == NULL) {
         gcclient = gconf_client_get_default();
@@ -281,7 +286,8 @@ static gchar *get_preferred_bda(void) {
 }
 
 void progress_cb(GwObex *obex, gint cmd, gint current, gint target,
-                 ObcContext *ctx) {
+                 ObcContext *ctx)
+{
     double speed;
     double tdelta;
     const char *unit = "bytes/s", *nl = "";
@@ -332,12 +338,14 @@ void progress_cb(GwObex *obex, gint cmd, gint current, gint target,
     fflush(stdout);
 }
 
-static void disconnect_cb(ObcContext *ctx, gpointer data) {
+static void disconnect_cb(ObcContext *ctx, gpointer data)
+{
     printf("\nDisconnected.\n");
     obc_reset(ctx, FALSE);
 }
 
-static gboolean cancel_cb(gpointer data) {
+static gboolean cancel_cb(gpointer data)
+{
     if (do_abort) {
         do_abort = FALSE;
         return TRUE;
@@ -345,7 +353,8 @@ static gboolean cancel_cb(gpointer data) {
     return FALSE;
 }
 
-static gboolean cmd_exit(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_exit(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (ctx->obex == NULL) {
         if (ctx->sk >= 0) {
             close(ctx->sk);
@@ -363,7 +372,8 @@ static gboolean cmd_exit(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
 }
 
 
-static void abort_sig(int sig) {
+static void abort_sig(int sig)
+{
     if (do_abort)
         cmd_exit(obc_ctx, 0, NULL, NULL);
     else {
@@ -372,7 +382,8 @@ static void abort_sig(int sig) {
     }
 }
 
-static gboolean cmd_cap(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_cap(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     gchar *cap, *fmt;
     gint cap_len;
     gboolean ret, prog, show_prog = FALSE;
@@ -400,7 +411,8 @@ static gboolean cmd_cap(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-void obc_show_progress(ObcContext *ctx, gboolean show) {
+void obc_show_progress(ObcContext *ctx, gboolean show)
+{
     ctx->show_progress = show;
     if (ctx->obex == NULL)
         return;
@@ -414,7 +426,8 @@ void obc_show_progress(ObcContext *ctx, gboolean show) {
 
 }
 
-static gboolean cmd_prog(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_prog(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     ctx->show_progress = !ctx->show_progress;
     obc_show_progress(ctx, ctx->show_progress);
     if (ctx->show_progress)
@@ -424,7 +437,8 @@ static gboolean cmd_prog(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static void cd_help(ObcContext *ctx, const char *name) {
+static void cd_help(ObcContext *ctx, const char *name)
+{
     printf("%s [directory]\n"
            "Change remote directory.\n"
            "No parameters change to root directory.\n"
@@ -432,7 +446,8 @@ static void cd_help(ObcContext *ctx, const char *name) {
            name);
 }
 
-static gboolean cmd_cd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_cd(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     gboolean ret;
 
     ret = gw_obex_chdir(ctx->obex, argc < 2 ? NULL : argv[1], err);
@@ -463,13 +478,15 @@ static gboolean cmd_cd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return ret;
 }
 
-static gboolean cmd_mkdir(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_mkdir(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (argc < 2)
         return FALSE;
     return gw_obex_mkdir(ctx->obex, argv[1], err);
 }
 
-static gboolean cmd_del(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_del(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     int i;
 
     if (argc < 2)
@@ -492,7 +509,8 @@ static gboolean cmd_del(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static gboolean cmd_exec(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_exec(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (argc < 2)
         return FALSE;
 
@@ -502,7 +520,8 @@ static gboolean cmd_exec(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static gboolean cmd_lcd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_lcd(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (argc < 2) {
         char *home = getenv("HOME");
         if (!home)
@@ -516,7 +535,8 @@ static gboolean cmd_lcd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static gboolean cmd_lls(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_lls(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     char *av[] = { "|", "ls", NULL, NULL };
 
     if (argc > 1)
@@ -525,7 +545,8 @@ static gboolean cmd_lls(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return cmd_exec(ctx, argc > 1 ? 3 : 2, av, err);
 }
 
-static gboolean cmd_lpwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_lpwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     char lpwd[PATH_MAX];
 
     if (getcwd(lpwd, sizeof(lpwd))) {
@@ -536,7 +557,8 @@ static gboolean cmd_lpwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return FALSE;
 }
 
-static gboolean cmd_pwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_pwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (ctx->cwd[0] == '\0') {
         printf("not connected\n");
         return FALSE;
@@ -547,21 +569,24 @@ static gboolean cmd_pwd(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     }
 }
 
-static gboolean cmd_copy(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_copy(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (argc < 3)
         return FALSE;
 
     return gw_obex_copy(ctx->obex, argv[1], argv[2], err);
 }
 
-static gboolean cmd_move(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_move(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (argc < 3)
         return FALSE;
 
     return gw_obex_move(ctx->obex, argv[1], argv[2], err);
 }
 
-static void conn_help(ObcContext *ctx, const char *name) {
+static void conn_help(ObcContext *ctx, const char *name)
+{
     printf("%s [-f | -p] [BT-name | BT-address]\n"
            "Connect to remote device\n"
            "If no device identifier was given the connection will be made to the\n"
@@ -574,7 +599,8 @@ static void conn_help(ObcContext *ctx, const char *name) {
            name);
 }
 
-static gboolean cmd_conn(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_conn(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     int c;
 
     while ((c = getopt(argc, argv, "PpfC:")) != -1) {
@@ -643,7 +669,8 @@ static gboolean cmd_conn(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static gboolean cmd_mtu(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_mtu(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     gint new_mtu;
 
     if (argc < 2)
@@ -661,22 +688,26 @@ static gboolean cmd_mtu(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return FALSE;
 }
 
-static gboolean cmd_sync(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_sync(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     ctx->async = FALSE;
     return TRUE;
 }
 
-static gboolean cmd_async(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_async(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     ctx->async = TRUE;
     return TRUE;
 }
 
-static gboolean cmd_iter(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_iter(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     g_main_context_iteration(NULL, FALSE);
     return TRUE;
 }
 
-static gboolean cmd_dc(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_dc(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     if (ctx->sk >= 0) {
         close(ctx->sk);
         ctx->sk = -1;
@@ -687,15 +718,16 @@ static gboolean cmd_dc(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static void scan_help(ObcContext *ctx, const char *name) {
+static void scan_help(ObcContext *ctx, const char *name)
+{
     printf("%s [-s]\n"
            "Scan for remote devices\n"
            "Parameters:\n"
            "-s\tShow results from last scan\n", name);
 }
 
-
-static gboolean cmd_scan(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_scan(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     GSList *l;
     int i, c;
     gboolean show;
@@ -730,7 +762,8 @@ static gboolean cmd_scan(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
     return TRUE;
 }
 
-static gboolean cmd_cat(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_cat(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     int i, c;
     char *type = NULL;
     gboolean prog, empty_name = FALSE;
@@ -789,7 +822,8 @@ static gboolean cmd_cat(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
 
 Command cmd_table[];
 
-static gboolean cmd_help(ObcContext *ctx, gint argc, gchar *argv[], gint *err) {
+static gboolean cmd_help(ObcContext *ctx, gint argc, gchar *argv[], gint *err)
+{
     Command *cmd;
 
     if (argc < 2) {
@@ -859,7 +893,8 @@ Command cmd_table[] = {
     { NULL }
 };
 
-static gboolean input_command(ObcContext *ctx, char *line, gint *err) {
+static gboolean input_command(ObcContext *ctx, char *line, gint *err)
+{
     Command *cmd, *match;
     gboolean ret;
     GError *gerr = NULL;
@@ -901,7 +936,8 @@ static gboolean input_command(ObcContext *ctx, char *line, gint *err) {
     return ret;
 }
 
-static void process_input(ObcContext *ctx, char *input) {
+static void process_input(ObcContext *ctx, char *input)
+{
     gint err;
     if (!input_command(ctx, input, &err)) {
         char *str = response_to_string(err);
@@ -912,7 +948,8 @@ static void process_input(ObcContext *ctx, char *input) {
     }
 }
 
-static void obc_reset(ObcContext *ctx, gboolean connect) {
+static void obc_reset(ObcContext *ctx, gboolean connect)
+{
     if (connect && ctx->user_bda == NULL) {
         printf("No BDA to connect to!\n");
         return;
@@ -996,7 +1033,8 @@ static void obc_reset(ObcContext *ctx, gboolean connect) {
        ctx->cwd[0] = '\0';
 } 
 
-void obc_init(ObcCfg *cfg) {
+void obc_init(ObcCfg *cfg)
+{
     ObcContext *ctx;
 
     ctx = g_new0(ObcContext, 1);
